# Contributing to mcpm.sh

Thank you for considering contributing to mcpm.sh! This document outlines the process for adding or updating MCP servers in the registry.

## Adding a New Server
Please follow the instructions in the [mcp-registry/README.md](mcp-registry/README.md) file.

## Website Development

Please follow the instructions in the [docs/dev_guide.md](docs/dev_guide.md) file.

## Code of Conduct

Please note that this project is released with a Contributor Code of Conduct. By participating in this project, you agree to abide by its terms.

## License

By contributing to this repository, you agree to license your contributions under the same license as this repository.
